@@ -1,6 +1,5 @@
 """ wbuilder """
-from .wbuilder import FromJSONBuild
 from .wbuilder import WebBuilder
 from .wbuilder import Css
 from .version import version as __version__
-__all__ = ["wbuilder"]
\ No newline at end of file
+__all__ = ["WebBuilder", "Css"]
\ No newline at end of file
